# HoloUR
[![pipeline status](https://gitlab.au.dk/hrc/common/holour/badges/master/pipeline.svg)](https://gitlab.au.dk/hrc/common/holour/-/commits/master)
[![coverage report](https://gitlab.au.dk/hrc/common/holour/badges/master/coverage.svg)](https://gitlab.au.dk/hrc/common/holour/-/commits/master)

Common data objects and stuff like that for HoloUR (python)
